@@ -6,7 +6,7 @@ char* extract_command_str(int flags,const char *filename,int do_extract,const ch
   char* _uname_m=uname_m();
   char* _uname=uname_s();
   char* _confdir=configdir();
-  char* exe=s_escape_string(cat(_confdir,"impls",SLASH,_uname_m,SLASH,_uname,SLASH,"7za",SLASH,"9.20",SLASH,"7za.exe",NULL));
+  char* exe=s_escape_string(cat(_confdir,"impls",DIRSEP,_uname_m,DIRSEP,_uname,DIRSEP,"7za",DIRSEP,"9.20",DIRSEP,"7za.exe",NULL));
   char *outputpath2=q(outputpath);
   char *filename2=q(filename);
   substitute_char('\\','/',outputpath2);
@@ -18,6 +18,9 @@ char* extract_command_str(int flags,const char *filename,int do_extract,const ch
   }else if(strcmp(type,"7za")==0) {
     ensure_directories_exist(outputpath2);
     str=cat(exe," ",do_extract?"x":"t"," -y -o",outputpath2," ",filename2,NULL);
+  }else if(strcmp(type,"cab")==0) {
+    if(do_extract)
+      str=cat("expand.exe /r \"-F:*\" ",filename2," ",outputpath2,NULL);
   }
   s(outputpath2),s(filename2),s(_confdir),s(_uname),s(_uname_m);
   return str;
